@@ -2,9 +2,13 @@
 *
 * DrawLegend.c
 *
+* Contains functions:
+*    DrawLegend
+*    background_legend
+*
 * Draws legend.
 *
-* Copyright  2008, 2009, 2010 Spencer A. Buckner
+* Copyright  2008, 2009, 2010, 2011 Spencer A. Buckner
 * http://savannah.gnu.org/projects/gsegrafix
 *
 * This file is part of GSEGrafix, a scientific and engineering plotting program.
@@ -32,7 +36,7 @@ void DrawLegend ( void )
    {
    /* Declare variables */
    int i, iplot, ifunc, nplots, nlines, index_plot_types, imesh, icontour, index, anchor_text;
-   unsigned int size, nchar;
+   unsigned int i1_str, i2_str, size, nchar;
    long int file_position, file_position_1;
    double x, y, x1, y1, x2, y2, x1_box, y1_box, x2_box, y2_box,
           xlegend, ylegend, zlegend, xanchor, yanchor,
@@ -98,7 +102,7 @@ void DrawLegend ( void )
       {
       fgets(line, maxline, fptr);
       size = strlen(&line[13]);
-      if ( (string = get_string(&line[13], &size)) != NULL )
+      if ( (string = get_string(&line[13], &i1_str, &i2_str, &size, 1)) != NULL )
          nchar = nchar + size + 1;
       }
 
@@ -112,7 +116,7 @@ void DrawLegend ( void )
       {
       fgets(line, maxline, fptr);
       size = strlen(&line[13]);
-      if ( (string = get_string(&line[13], &size)) != NULL )
+      if ( (string = get_string(&line[13], &i1_str, &i2_str, &size, 1)) != NULL )
          {
          strcpy(&legend_str[index], string);
          index = index + size + 1;
@@ -154,7 +158,7 @@ void DrawLegend ( void )
             {
             memset(anchor, 0, sizeof(anchor));
             size = strlen(&line[13]);
-            if ( (string = get_string(&line[13], &size)) != NULL )
+            if ( (string = get_string(&line[13], &i1_str, &i2_str, &size, 0)) != NULL )
                strncpy(&anchor[0], string, 9);
             else
                {
@@ -181,7 +185,7 @@ void DrawLegend ( void )
                                 GNOME_TYPE_CANVAS_TEXT,
                                 "text", legend_str,
                                 "font-desc", font_legend,
-                                "fill_color_rgba", 0x000000FF,
+                                "fill_color_rgba", canvas_fg_color,
                                 NULL);
 
 
@@ -307,7 +311,7 @@ void DrawLegend ( void )
    /* Draw legend background rectangles */
    gnome_canvas_item_get_bounds(text, &x1, &y1, &x2, &y2);
    height_lines = (y2 - y1)/nlines;
-   backgound_legend(legend_str, height_lines, x1 - 70.0, y1);
+   background_legend(legend_str, height_lines, x1 - 70.0, y1);
    gnome_canvas_item_raise_to_top(text);
 
 
@@ -408,7 +412,7 @@ void DrawLegend ( void )
                y2 = y - dy_bar[i-1];
 
                DrawBar(x1+1.0, y1, x2-1.0, y2, fill_colors_rgba[iplot-1], outline_colors_rgba[iplot-1]);
-               DrawBar(x1, y1+1.0, x2, y2-1.0, color_rgba[16], color_rgba[3]);
+               DrawBar(x1, y1+1.0, x2, y2-1.0, 0xFFFFFF00, canvas_bg_color);
                }
             }
          }
@@ -453,20 +457,20 @@ void DrawLegend ( void )
             if ( (pchar = strchr(color_string, stylechar1[iplot-1])) != NULL )
                {
                index = pchar - &color_string[0];
-               DrawContour(x1, y1, x2, y2, color_rgba[index], 0x00000000, styleflags[iplot-1]);
+               DrawContour(x1, y1, x2, y2, color_rgba[index], 0xFFFFFF00, styleflags[iplot-1]);
                }
             }
 
          else if ( styleflags[iplot-1] == 3 )
             {
             /* 2d contour plot */
-            DrawContour(x1, y1, x2, y2, stylecolor1[iplot-1], 0x00000000, styleflags[iplot-1]);
+            DrawContour(x1, y1, x2, y2, stylecolor1[iplot-1], 0xFFFFFF00, styleflags[iplot-1]);
             }
 
          else if ( styleflags[iplot-1] == 7 )
             {
             /* 2d contour plot */
-            DrawContour(x1, y1, x2, y2, color_rgba[3], 0x00000000, styleflags[iplot-1]);
+            DrawContour(x1, y1, x2, y2, color_rgba[3], 0xFFFFFF00, styleflags[iplot-1]);
             }
 
          else if ( styleflags[iplot-1] == 2 || styleflags[iplot-1] == 4 )
@@ -509,7 +513,7 @@ void DrawLegend ( void )
 
 
 
-void backgound_legend ( char *legend_str, double height_lines, double x1, double y1 )
+void background_legend ( char *legend_str, double height_lines, double x1, double y1 )
    {
    /* Declare variables */
    int i, i1, nline;
@@ -541,7 +545,7 @@ void backgound_legend ( char *legend_str, double height_lines, double x1, double
                                          "y", y,
                                          "anchor", GTK_ANCHOR_NORTH,
                                          "font-desc", font_legend,
-                                         "fill_color_rgba", 0x00000000,
+                                         "fill_color_rgba", 0xFFFFFF00,
                                          NULL);
             gnome_canvas_item_get_bounds(text, &x1rec, &y1rec, &x2rec, &y2rec);
             gtk_object_destroy((GtkObject*) text);
@@ -556,8 +560,8 @@ void backgound_legend ( char *legend_str, double height_lines, double x1, double
                                               "x2", x22,
                                               "y1", y11,
                                               "y2", y22,
-                                              "fill_color_rgba", 0xFFFFFFFF,
-                                              "outline_color_rgba", 0xFFFFFFFF,
+                                              "fill_color_rgba", canvas_bg_color,
+                                              "outline_color_rgba", canvas_bg_color,
                                               "width_pixels", 1,
                                               NULL);
             }
