@@ -23,7 +23,7 @@
 *
 * Functions draw lines and plot symbols.
 *
-* Copyright  2008, 2009, 2010 Spencer A. Buckner
+* Copyright  2008, 2009, 2010, 2011 Spencer A. Buckner
 * http://savannah.gnu.org/projects/gsegrafix
 *
 * This file is part of GSEGrafix, a scientific and engineering plotting program.
@@ -858,12 +858,12 @@ void DrawContour ( double x1, double y1, double x2, double y2,
       {
       /* 2d contour plot */
       gnome_canvas_item_set(ellipse1,
-                            "fill_color_rgba", 0x00000000,
+                            "fill_color_rgba", 0xFFFFFF00,
                             "outline_color_rgba", fill_color_rgba,
                             NULL);
 
       gnome_canvas_item_set(ellipse2,
-                            "fill_color_rgba", 0x00000000,
+                            "fill_color_rgba", 0xFFFFFF00,
                             "outline_color_rgba", fill_color_rgba,
                             NULL);
       }
@@ -872,12 +872,12 @@ void DrawContour ( double x1, double y1, double x2, double y2,
       {
       /* 2d contour plot */
       gnome_canvas_item_set(ellipse1,
-                            "fill_color_rgba", 0x00000000,
+                            "fill_color_rgba", 0xFFFFFF00,
                             "outline_color_rgba", 0xFF8000FF,
                             NULL);
 
       gnome_canvas_item_set(ellipse2,
-                            "fill_color_rgba", 0x00000000,
+                            "fill_color_rgba", 0xFFFFFF00,
                             "outline_color_rgba", 0xFF0000FF,
                             NULL);
       }
@@ -886,12 +886,12 @@ void DrawContour ( double x1, double y1, double x2, double y2,
       {
       /* 3d contour plot */
       gnome_canvas_item_set(ellipse1,
-                            "fill_color_rgba", 0x00000000,
+                            "fill_color_rgba", 0xFFFFFF00,
                             "outline_color_rgba", outline_color_rgba,
                             NULL);
 
       gnome_canvas_item_set(ellipse2,
-                            "fill_color_rgba", 0x00000000,
+                            "fill_color_rgba", 0xFFFFFF00,
                             "outline_color_rgba", outline_color_rgba,
                             NULL);
       }
