@@ -4,7 +4,7 @@
 *
 * Handles events.
 *
-* Copyright  2008, 2009, 2010 Spencer A. Buckner
+* Copyright  2008, 2009, 2010, 2011 Spencer A. Buckner
 * http://savannah.gnu.org/projects/gsegrafix
 *
 * This file is part of GSEGrafix, a scientific and engineering plotting program.
@@ -76,17 +76,25 @@ gboolean EventHandler ( GtkWidget *window, GdkEvent *event )
          else if ( state == 0 && keyval == 65362 )
             {
             /* Up arrow */
-            if ( strcmp(p_plot_param->axis_type, "linear") == 0 &&
-                 contour_labels_flag == 1 )
-               ViewLabelCallback(1);
+            if ( strcmp(p_plot_param->axis_type, "linear") == 0 )
+               {
+               if ( contour_labels_flag == 1 )
+                  ViewLabelCallback(1);
+               else if ( coords_display_flag == 1 )
+                  ViewCoordsDisplayCallback(1);
+               }
             }
 
          else if ( state == 0 && keyval == 65364 )
             {
             /* Down arrow */
-            if ( strcmp(p_plot_param->axis_type, "linear") == 0 &&
-                 contour_labels_flag == 1 )
-               ViewLabelCallback(-1);
+            if ( strcmp(p_plot_param->axis_type, "linear") == 0 )
+               {
+               if ( contour_labels_flag == 1 )
+                  ViewLabelCallback(-1);
+               else if ( coords_display_flag == 1 )
+                  ViewCoordsDisplayCallback(-1);
+               }
             }
 
          break;
@@ -123,8 +131,8 @@ gboolean EventHandler ( GtkWidget *window, GdkEvent *event )
                                                       "x2", x2_window,
                                                       "y1", y1_window,
                                                       "y2", y2_window,
-                                                      "fill_color_rgba", 0xC0C0C040,
-                                                      "outline_color_rgba", 0x000000FF,
+                                                      "fill_color_rgba", zoom_fill_color,
+                                                      "outline_color_rgba", canvas_fg_color,
                                                       "width_pixels", 1,
                                                       NULL);
 
@@ -144,7 +152,7 @@ gboolean EventHandler ( GtkWidget *window, GdkEvent *event )
                if ( contour_label != NULL )
                   {
                   memset(label, 0, sizeof(label));
-                  snprintf(label, sizeof(string), "%g", *contour_label);
+                  snprintf(label, sizeof(label), "%g", *contour_label);
                   text = gnome_canvas_item_new(group,
                                                GNOME_TYPE_CANVAS_TEXT,
                                                "text", label,
@@ -153,7 +161,7 @@ gboolean EventHandler ( GtkWidget *window, GdkEvent *event )
                                                "anchor", GTK_ANCHOR_CENTER,
                                                "justification", GTK_JUSTIFY_CENTER,
                                                "font-desc", font_text,
-                                               "fill_color_rgba", 0x000000FF,
+                                               "fill_color_rgba", canvas_fg_color,
                                                NULL);
 
                   gnome_canvas_item_get_bounds(text, &xtext1, &ytext1, &xtext2, &ytext2);
@@ -164,8 +172,8 @@ gboolean EventHandler ( GtkWidget *window, GdkEvent *event )
                                                     "x2", xtext2,
                                                     "y1", ytext1,
                                                     "y2", ytext2,
-                                                    "fill_color_rgba", 0xFFFFFFFF,
-                                                    "outline_color_rgba", 0xFFFFFFFF,
+                                                    "fill_color_rgba", canvas_bg_color,
+                                                    "outline_color_rgba", canvas_bg_color,
                                                     "width_pixels", 1,
                                                     NULL);
 
@@ -258,37 +266,6 @@ gboolean EventHandler ( GtkWidget *window, GdkEvent *event )
             g_object_set(zoom_rectangle, "x1", x1, "x2", x2, "y1", y1, "y2", y2, NULL);
             }
 
-         /* Write x and y coords of mouse in lower left corner of plot window */
-         if ( flag_2d == 1 && coords_display_flag == 1 )
-            {
-            /* Grab mouse pointer */
-            if ( gdk_pointer_is_grabbed() != TRUE )
-               gdk_pointer_grab(window->window,
-                                TRUE,
-                                GDK_POINTER_MOTION_MASK,
-                                window->window,
-                                NULL,
-                                GDK_CURRENT_TIME);
-
-            /* Get mouse window coordinates */
-            xmouse = ((GdkEventMotion*) event)->x;
-            ymouse = ((GdkEventMotion*) event)->y;
-
-            /* Write values to plot window */
-            ViewCoordsDisplayCallback();
-            memset(string, 0, sizeof(string));
-            if ( xy_coords_data[0] != NULL && xy_coords_data[1] != NULL )
-               {
-               if ( flag_2d_rect == 1 )
-                  snprintf(string, sizeof(string), "x = %g\ny = %g",
-                           *xy_coords_data[0], *xy_coords_data[1]);
-               else if ( flag_polar == 1 )
-                  snprintf(string, sizeof(string), "\xCE\xB8 = %g\nr = %g",
-                           *xy_coords_data[0], *xy_coords_data[1]);
-               }
-            g_object_set(text_xy_coords_data, "text", string, NULL);
-            }
-
          /* Write z values of 2d-contour data in upper left corner of plot window */
          if ( flag_2d_rect == 1 && contour_labels_flag == 1 )
             {
@@ -308,14 +285,67 @@ gboolean EventHandler ( GtkWidget *window, GdkEvent *event )
             ViewLabelCallback(0);
             memset(string, 0, sizeof(string));
             if ( zcontour_data != NULL )
-               snprintf(string, sizeof(string), "plot %d\nz = %g",
+               snprintf(string, sizeof(string), "contour plot %d\nz = %g",
                         icontour_plots, *zcontour_data);
             else
-               snprintf(string, sizeof(string), "plot %d",
+               snprintf(string, sizeof(string), "contour plot %d",
                         icontour_plots);
             g_object_set(text_contour_data, "text", string, NULL);
             }
 
+         /* Write plot type in upper left corner of plot window;                    */
+         /* write x and y coordinates of mouse in lower left corner of plot window; */
+         /* write corresponding z values below cursor position                      */
+         if ( flag_2d == 1 && coords_display_flag == 1 )
+            {
+            /* Grab mouse pointer */
+            if ( gdk_pointer_is_grabbed() != TRUE )
+               gdk_pointer_grab(window->window,
+                                TRUE,
+                                GDK_POINTER_MOTION_MASK,
+                                window->window,
+                                NULL,
+                                GDK_CURRENT_TIME);
+
+            /* Get mouse window coordinates */
+            xmouse = ((GdkEventMotion*) event)->x;
+            ymouse = ((GdkEventMotion*) event)->y;
+
+            /* Write plot type to plot window */
+            ViewCoordsDisplayCallback(0);
+            memset(string, 0, sizeof(string));
+            if ( plot_type_data[itotal_plots-1] > 0 )
+               snprintf(string, sizeof(string), "color plot %d",
+                        icolor_plots);
+            else if ( plot_type_data[itotal_plots-1] < 0 )
+               snprintf(string, sizeof(string), "contour plot %d",
+                        icontour_plots);
+            g_object_set(text_plot_data, "text", string, NULL);
+
+            /* Write x and y values to plot window */
+            memset(string, 0, sizeof(string));
+            if ( xy_coords_data[0] != NULL && xy_coords_data[1] != NULL )
+               {
+               if ( flag_2d_rect == 1 )
+                  snprintf(string, sizeof(string), "x = %g\ny = %g",
+                           *xy_coords_data[0], *xy_coords_data[1]);
+               else if ( flag_polar == 1 )
+                  snprintf(string, sizeof(string), "\xCE\xB8 = %g\nr = %g",
+                           *xy_coords_data[0], *xy_coords_data[1]);
+               }
+            g_object_set(text_xy_coords_data, "text", string, NULL);
+
+            /* Write z value below cursor position */
+            memset(string, 0, sizeof(string));
+            if ( z_coords_data != NULL )
+               {
+               if ( flag_2d_rect == 1 )
+                  snprintf(string, sizeof(string), "z = %g", *z_coords_data);
+               }
+            g_object_set(text_z_coords_data,
+                         "x", xmouse, "y", ymouse+10.0, "text", string, NULL);
+            }
+
          break;
 
       case GDK_BUTTON_RELEASE:
