@@ -21,7 +21,7 @@
 *    find_indices
 *    search_compare_ascending
 *    search_compare_descending
-*    get_string_size
+*    get_string
 *    put_pixel
 *
 * Rotation matrices:
@@ -38,7 +38,7 @@
 *          -sin(theta) cos(theta) 0
 *                    0          0 1]
 *
-* Copyright  2008, 2009, 2010 Spencer A. Buckner
+* Copyright  2008, 2009, 2010, 2011 Spencer A. Buckner
 * http://savannah.gnu.org/projects/gsegrafix
 *
 * This file is part of GSEGrafix, a scientific and engineering plotting program.
@@ -516,7 +516,119 @@ int search_compare_descending ( const void *p1, const void *p2 )
    }
 
 
-char * get_string ( char *string, unsigned int *size )
+char * get_string ( char *string, unsigned int *i1_str, unsigned int *i2_str,
+                    unsigned int *size, int flag )
+   {
+   /* Declare variables */
+   int i, i1, i2, j;
+   unsigned int strvalue;
+   char *pchar = NULL;
+   const char *error_str[] =
+      { "Invalid Unicode specification;\n"
+        "hexadecimal format is \\xhh;\n"
+        "octal format is \\ooo.",
+        "Invalid Unicode specification;\n"
+        "maximum value is:\n"
+        "   FF hexadecimal or\n"
+        "   377 octal." };
+
+
+   /* Get initial string */
+   free(string_get);
+   string_get = NULL;
+   string_get = xmalloc(*size + 1);
+   memset(string_get, 0, *size + 1);
+   strcpy(string_get, string);
+
+
+   /* Get string limits */
+   i = 0;
+   while ( (string_get[i] == ' ' || string_get[i] == '\t') && i < (int) *size )
+      i++;
+
+   if ( string_get[i] == '#' || string_get[i] != '\"' )
+      return NULL;
+
+   i1 = i + 1;
+   if ( (pchar = strchr(&string_get[i1], '\"')) == NULL )
+      return NULL;
+   *pchar = '\0';
+   i2 = i1 + pchar - &string_get[i1] - 1;
+
+
+   /************************************************************************
+   * Find escape sequences                                                 *
+   * Used for text which may contain escape sequences.                     *
+   * Not used for text which should not contain escape sequences.          *
+   * Not used for file names, which can contain any character except '\0'. *
+   ************************************************************************/
+   if ( flag == 1 )
+      for ( i=i1; i<=i2; i++ )
+         {
+         /* Find escaped instances of \ */
+         if ( string_get[i] == '\\' && string_get[i+1] == '\\' )
+            {
+            for ( j=i; j<=i2; j++ )
+               string_get[j] = string_get[j+1];
+            i2--;
+            }
+
+          /* Find newline escape sequences \n */
+         else if ( string_get[i] == '\\' && string_get[i+1] == 'n' )
+            {
+            string_get[i] = '\n';
+            for ( j=i+1; j<=i2; j++ )
+               string_get[j] = string_get[j+1];
+            i2--;
+            }
+
+         /* Find Unicode hexadecimal or octal escape sequences */
+         else if ( string_get[i] == '\\' && string_get[i+1] != 'n' )
+            {
+            /* Check for hexadecimal or octal format */
+            if ( string_get[i+1] == 'x' &&
+                 strchr("0123456789abcdefABCDEF", string_get[i+2]) != NULL &&
+                 strchr("0123456789abcdefABCDEF", string_get[i+3]) != NULL )
+               sscanf(&string_get[i+2], "%2x", &strvalue);
+
+            else if ( strchr("01234567", string_get[i+1]) != NULL &&
+                      strchr("01234567", string_get[i+2]) != NULL &&
+                      strchr("01234567", string_get[i+3]) != NULL )
+               sscanf(&string_get[i+1], "%3o", &strvalue);
+
+            else
+               {
+               ErrorDialog(error_str[0]);
+               exit(1);
+               }
+
+            /* Check Unicode value */
+            if ( strvalue > 255 )
+               {
+               ErrorDialog(error_str[1]);
+               exit(1);
+               }
+
+            /* Modify string */
+            string_get[i] = strvalue;
+            for ( j=i+1; j<=i2-3; j++ )
+               string_get[j] = string_get[j+3];
+            i2 = i2 - 3;
+            }
+         }
+   string_get[i2+1] = '\0';
+
+
+   /* Calculate return variables */
+   *i1_str = (unsigned int) i1;
+   *i2_str = (unsigned int) i2;
+   *size = (unsigned int) i2 - (unsigned int) i1 + 1;
+
+   return &string_get[i1];
+   }
+
+
+char * get_string_old ( char *string, unsigned int *size )
    {
    /* Declare variables */
    int i, i1, i2, j;
