@@ -4,7 +4,7 @@
 *
 * Calculates polar plot of input data.
 *
-* Copyright  2008, 2009, 2010 Spencer A. Buckner
+* Copyright  2008, 2009, 2010, 2011 Spencer A. Buckner
 * http://savannah.gnu.org/projects/gsegrafix
 *
 * This file is part of GSEGrafix, a scientific and engineering plotting program.
@@ -35,6 +35,7 @@ void PolarPlot ( void )
    /* Declare variables */
    int i, j, ifunc, nyvalues, nrvalues, iplot, nplots, npts, index, index_stemflags,
        anchor, window_width, window_height;
+   guint32 fill_color, outline_color;
    double rmin, rmax, xorigin, yorigin, radius, radius_grid, rscale,
           x, y, x1, y1, x2, y2, xtext1, xtext2, ytext1, ytext2,
           theta, theta_max, theta_minor, r, r1, dr, width_xtick_label;
@@ -118,7 +119,7 @@ void PolarPlot ( void )
                                               "x2", x2,
                                               "y1", y1,
                                               "y2", y2,
-                                              "fill_color_rgba", 0x00000000,
+                                              "fill_color_rgba", 0xFFFFFF00,
                                               "outline_color_rgba", gridcolor,
                                               "width_pixels", 1,
                                               NULL);
@@ -153,7 +154,7 @@ void PolarPlot ( void )
          line = gnome_canvas_item_new(group,
                                       GNOME_TYPE_CANVAS_LINE,
                                       "points", points,
-                                      "fill_color_rgba", 0x000000FF,
+                                      "fill_color_rgba", canvas_fg_color,
                                       "width_pixels", 1,
                                       NULL);
 
@@ -170,7 +171,7 @@ void PolarPlot ( void )
                line = gnome_canvas_item_new(group,
                                             GNOME_TYPE_CANVAS_LINE,
                                             "points", points,
-                                            "fill_color_rgba", 0x000000FF,
+                                            "fill_color_rgba", canvas_fg_color,
                                             "width_pixels", 1,
                                             NULL);
                }
@@ -195,7 +196,7 @@ void PolarPlot ( void )
       line = gnome_canvas_item_new(group,
                                    GNOME_TYPE_CANVAS_LINE,
                                    "points", points,
-                                   "fill_color_rgba", 0x000000FF,
+                                   "fill_color_rgba", canvas_fg_color,
                                    "width_pixels", 1,
                                    NULL);
 
@@ -217,8 +218,8 @@ void PolarPlot ( void )
                                      "x2", xorigin + radius,
                                      "y1", yorigin - radius,
                                      "y2", yorigin + radius,
-                                     "fill_color_rgba", 0x00000000,
-                                     "outline_color_rgba", 0x000000FF,
+                                     "fill_color_rgba", 0xFFFFFF00,
+                                     "outline_color_rgba", canvas_fg_color,
                                      "width_pixels", 2,
                                      NULL);
 
@@ -261,7 +262,7 @@ void PolarPlot ( void )
                                       "y", y,
                                       "anchor", anchor,
                                       "font-desc", font_tick_labels,
-                                      "fill_color_rgba", 0x000000FF,
+                                      "fill_color_rgba", canvas_fg_color,
                                       NULL);
 
          if ( i == 1 )
@@ -292,7 +293,7 @@ void PolarPlot ( void )
             line = gnome_canvas_item_new(group,
                                          GNOME_TYPE_CANVAS_LINE,
                                          "points", points,
-                                         "fill_color_rgba", 0x000000FF,
+                                         "fill_color_rgba", canvas_fg_color,
                                          "width_pixels", 1,
                                          NULL);
             }
@@ -307,7 +308,7 @@ void PolarPlot ( void )
          line = gnome_canvas_item_new(group,
                                       GNOME_TYPE_CANVAS_LINE,
                                       "points", points,
-                                      "fill_color_rgba", 0x000000FF,
+                                      "fill_color_rgba", canvas_fg_color,
                                       "width_pixels", 1,
                                       "last_arrowhead", TRUE,
                                       "arrow_shape_a", 10.0,
@@ -342,7 +343,7 @@ void PolarPlot ( void )
          line = gnome_canvas_item_new(group,
                                       GNOME_TYPE_CANVAS_LINE,
                                       "points", points,
-                                      "fill_color_rgba", 0x000000FF,
+                                      "fill_color_rgba", canvas_fg_color,
                                       "width_pixels", 1,
                                       "last_arrowhead", TRUE,
                                       "arrow_shape_a", 10.0,
@@ -497,7 +498,7 @@ void PolarPlot ( void )
    PlotSymbols();
 
 
-   /* Draw r tick-mark labels on translucent white rectangles */
+   /* Draw r tick-mark labels on translucent rectangles */
    if ( strcmp(p_plot_param->plot_box, "on")      == 0 &&
         strcmp(p_plot_param->y_tick_marks, "on")  == 0 &&
         strcmp(p_plot_param->y_tick_labels, "on") == 0 )
@@ -522,19 +523,21 @@ void PolarPlot ( void )
                                       "y", y,
                                       "anchor", GTK_ANCHOR_EAST,
                                       "font-desc", font_tick_labels,
-                                      "fill_color_rgba", 0x000000FF,
+                                      "fill_color_rgba", canvas_fg_color,
                                       NULL);
 
          gnome_canvas_item_get_bounds(text, &xtext1, &ytext1, &xtext2, &ytext2);
 
+         fill_color = canvas_bg_color - 0xFF + 0xC0;
+         outline_color = canvas_bg_color - 0xFF + 0xC0;
          rectangle = gnome_canvas_item_new(group,
                                            GNOME_TYPE_CANVAS_RECT,
                                            "x1", xtext1,
                                            "x2", xtext2,
                                            "y1", ytext1,
                                            "y2", ytext2,
-                                           "fill_color_rgba", 0xFFFFFFC0,
-                                           "outline_color_rgba", 0xFFFFFFC0,
+                                           "fill_color_rgba", fill_color,
+                                           "outline_color_rgba", outline_color,
                                            "width_pixels", 1,
                                            NULL);
 
