@@ -4,7 +4,7 @@
 *
 * Reads plot-parameter file.
 *
-* Copyright  2008, 2009, 2010 Spencer A. Buckner
+* Copyright  2008, 2009, 2010, 2011 Spencer A. Buckner
 * http://savannah.gnu.org/projects/gsegrafix
 *
 * This file is part of GSEGrafix, a scientific and engineering plotting program.
@@ -34,10 +34,10 @@ void ReadParamFile ( void )
    {
    /* Declare variables */
    int i, j, ch, iplot, nplots, iformat, nformat, nfilenames_total, nformats_total,
-       index_filenames, index_formats, index_plot_types, index_bin_values,
+       index, index_filenames, index_formats, index_plot_types, index_bin_values,
        index_bin_refs, ibinwidth, index_stemflags, ibinvalue, ibinref, ininterp,
        istemflag, imeshcolor, icontourcolor, stylesize;
-   unsigned int index, size;
+   unsigned int i1_str, i2_str, size;
    char *string, *pchar, character;
    extern char color_string[];   /* color-specification characters "kaswrylqbfmogtnpx" */
    const char *error_str[] =
@@ -152,7 +152,7 @@ void ReadParamFile ( void )
             {
             iplot++;
             size = strlen(&line[9]);
-            if ( (string = get_string(&line[9], &size)) != NULL )
+            if ( (string = get_string(&line[9], &i1_str, &i2_str, &size, 0)) != NULL )
                nfilenames[iplot-1] = size + 1;
             else
                {
@@ -181,7 +181,7 @@ void ReadParamFile ( void )
             {
             iformat++;
             size = strlen(&line[11]);
-            if ( (string = get_string(&line[11], &size)) != NULL )
+            if ( (string = get_string(&line[11], &i1_str, &i2_str, &size, 0)) != NULL )
                nformats[iformat-1] = size + 1;
             else
                {
@@ -198,6 +198,49 @@ void ReadParamFile ( void )
       }
 
 
+   /* Get background color */
+   rewind(fptr);
+   while ( fgets(line, maxline, fptr) != NULL )
+      {
+      if ( strncmp(line, "background_color", 16) == 0 )
+         {
+         size = strlen(&line[16]);
+         if ( (string = get_string(&line[16], &i1_str, &i2_str, &size, 0)) != NULL )
+            if ( strcmp(string, "black") == 0 )
+               {
+               canvas_bg_color = 0x000000FF;   /* black */
+               canvas_fg_color = 0xFFFFFFFF;   /* white */
+               }
+         }
+
+      else if ( strncmp(line, "background_image", 16) == 0 )
+         {
+         size = strlen(&line[16]);
+         if ( (string = get_string(&line[16], &i1_str, &i2_str, &size, 0)) != NULL )
+            {
+            background_image_file = xmalloc(size + 1);
+            strcpy(background_image_file, string);
+            }
+         index = 16 + i2_str + 2;
+         size = strlen(&line[index]);
+         if ( (string = get_string(&line[index], &i1_str, &i2_str, &size, 0)) != NULL )
+            {
+            if ( strcmp(string, "center") == 0 )
+               background_image_style = 1;
+            else if ( strcmp(string, "fill") == 0 )
+               background_image_style = 2;
+            else if ( strcmp(string, "scale") == 0 )
+               background_image_style = 3;
+            else if ( strcmp(string, "zoom") == 0 )
+               background_image_style = 4;
+            }
+         }
+
+      else if ( strncmp(line, "#####", 5) == 0 )
+         break;
+      }
+
+
    /* Allocate memory for plot parameters */
    filenames           = xmalloc(nfilenames_total*sizeof(char));
    formats             = xmalloc(nformats_total*sizeof(char));
@@ -278,8 +321,8 @@ void ReadParamFile ( void )
    /* Set default 3d-mesh colors and 3d-contour colors */
    for ( i=1; i<=nplots; i++ )
       {
-      meshcolors[i-1] = 0x000000FF;
-      contourcolors[i-1] = 0x000000FF;
+      meshcolors[i-1] = canvas_fg_color;
+      contourcolors[i-1] = canvas_fg_color;
       }
 
 
@@ -295,7 +338,7 @@ void ReadParamFile ( void )
             {
             iplot++;
             size = strlen(&line[9]);
-            if ( (string = get_string(&line[9], &size)) != NULL )
+            if ( (string = get_string(&line[9], &i1_str, &i2_str, &size, 0)) != NULL )
                {
                strcpy(&filenames[index_filenames], string);
                index_filenames = index_filenames + nfilenames[iplot-1];
@@ -321,7 +364,7 @@ void ReadParamFile ( void )
             {
             iformat++;
             size = strlen(&line[11]);
-            if ( (string = get_string(&line[11], &size)) != NULL )
+            if ( (string = get_string(&line[11], &i1_str, &i2_str, &size, 0)) != NULL )
                {
                strcpy(&formats[index_formats], string);
                index_formats = index_formats + nformats[iformat-1];
@@ -341,7 +384,7 @@ void ReadParamFile ( void )
       if ( strncmp(line, "axis_type", 9) == 0 )
          {
          size = strlen(&line[9]);
-         if ( (string = get_string(&line[9], &size)) != NULL )
+         if ( (string = get_string(&line[9], &i1_str, &i2_str, &size, 0)) != NULL )
             strncpy(&p_plot_param->axis_type[0], string, 8);
          }
 
@@ -373,7 +416,7 @@ void ReadParamFile ( void )
             {
             iplot++;
             size = strlen(&line[9]);
-            if ( (string = get_string(&line[9], &size)) != NULL )
+            if ( (string = get_string(&line[9], &i1_str, &i2_str, &size, 0)) != NULL )
                {
                strncpy(&plot_types[index_plot_types], string, 9);
                index_plot_types = index_plot_types + 10;
@@ -435,7 +478,7 @@ void ReadParamFile ( void )
                   fill_colors_rgba[iplot-1]    = stylecolor2[iplot-1];         /* set specified fill color */
                   outline_colors_rgba[iplot-1] = stylecolor2[iplot-1];         /* set specified outline color */
                   if ( (pchar = strchr("ctsiphb", stylechar1[iplot-1])) != NULL )
-                     fill_colors_rgba[iplot-1] = color_rgba[3];                /* set fill color white */
+                     fill_colors_rgba[iplot-1] = canvas_bg_color;             /* set fill color to background color */
                   if ( (pchar = strchr("cCtTsSiIpPhH+xra", stylechar1[iplot-1])) != NULL )
                      stylesizes[iplot-1] = 6;                                  /* set default symbol size */
                   if ( sscanf(&line[10], " %*c %*s %d", &stylesize) == 1 )
@@ -460,7 +503,7 @@ void ReadParamFile ( void )
                   fill_colors_rgba[iplot-1]    = stylecolor2[iplot-1];         /* set specified fill color */
                   outline_colors_rgba[iplot-1] = stylecolor2[iplot-1];         /* set specified outline color */
                   if ( (pchar = strchr("ctsiphb", stylechar1[iplot-1])) != NULL )
-                     fill_colors_rgba[iplot-1] = color_rgba[3];                /* set fill color white */
+                     fill_colors_rgba[iplot-1] = canvas_bg_color;              /* set fill color to background color */
                   if ( (pchar = strchr("cCtTsSiIpPhH+xra", stylechar1[iplot-1])) != NULL )
                      stylesizes[iplot-1] = 6;                                  /* set default symbol size */
                   if ( sscanf(&line[10], " %*c %*c %d", &stylesize) == 1 )
@@ -472,7 +515,7 @@ void ReadParamFile ( void )
                       strcmp(p_plot_param->axis_type, "linear") == 0 )
                {
                size = strlen(&line[10]);
-               if ( (string = get_string(&line[10], &size)) != NULL )
+               if ( (string = get_string(&line[10], &i1_str, &i2_str, &size, 0)) != NULL )
                   {
                   /************************************************************
                   *
@@ -497,7 +540,7 @@ void ReadParamFile ( void )
                       strcmp(p_plot_param->axis_type, "linear") == 0 )
                {
                size = strlen(&line[10]);
-               if ( (string = get_string(&line[10], &size)) != NULL )
+               if ( (string = get_string(&line[10], &i1_str, &i2_str, &size, 0)) != NULL )
                   {
                   /************************************************************
                   *
@@ -552,7 +595,7 @@ void ReadParamFile ( void )
                size = strlen(&line[10]);
                if ( (strcmp(&plot_types[index_plot_types], "color") == 0 ||
                      strcmp(&plot_types[index_plot_types], "mesh")  == 0) &&
-                    (string = get_string(&line[10], &size)) != NULL )
+                    (string = get_string(&line[10], &i1_str, &i2_str, &size, 0)) != NULL )
                   {
                   /************************************************************
                   *
@@ -649,7 +692,7 @@ void ReadParamFile ( void )
       if ( strncmp(line, "axis_scale", 10) == 0 )
          {
          size = strlen(&line[10]);
-         if ( (string = get_string(&line[10], &size)) != NULL )
+         if ( (string = get_string(&line[10], &i1_str, &i2_str, &size, 0)) != NULL )
             strncpy(&p_plot_param->axis_scale[0], string, 5);
          }
 
@@ -694,7 +737,7 @@ void ReadParamFile ( void )
       else if ( strncmp(line, "minor_ticks", 11) == 0 )
          {
          size = strlen(&line[11]);
-         if ( (string = get_string(&line[11], &size)) != NULL )
+         if ( (string = get_string(&line[11], &i1_str, &i2_str, &size, 0)) != NULL )
             {
             strncpy(&p_plot_param->minor_ticks[0], string, 3);
             if ( strcmp(string, "on") == 0 )
@@ -705,7 +748,7 @@ void ReadParamFile ( void )
       else if ( strncmp(line, "grid", 4) == 0 )
          {
          size = strlen(&line[4]);
-         if ( (string = get_string(&line[4], &size)) != NULL &&
+         if ( (string = get_string(&line[4], &i1_str, &i2_str, &size, 0)) != NULL &&
               strcmp(string, "off") == 0 )
             {
             strncpy(&p_plot_param->grid[0], string, 3);
@@ -732,7 +775,7 @@ void ReadParamFile ( void )
       else if ( strncmp(line, "xlabel", 6) == 0 )
          {
          size = strlen(&line[6]);
-         if ( (string = get_string(&line[6], &size)) != NULL )
+         if ( (string = get_string(&line[6], &i1_str, &i2_str, &size, 1)) != NULL )
             {
             xlabel = xmalloc(size + 1);
             strcpy(xlabel, string);
@@ -742,7 +785,7 @@ void ReadParamFile ( void )
       else if ( strncmp(line, "ylabel", 6) == 0 )
          {
          size = strlen(&line[6]);
-         if ( (string = get_string(&line[6], &size)) != NULL )
+         if ( (string = get_string(&line[6], &i1_str, &i2_str, &size, 1)) != NULL )
             {
             ylabel = xmalloc(size + 1);
             strcpy(ylabel, string);
@@ -752,7 +795,7 @@ void ReadParamFile ( void )
       else if ( strncmp(line, "zlabel", 6) == 0 )
          {
          size = strlen(&line[6]);
-         if ( (string = get_string(&line[6], &size)) != NULL )
+         if ( (string = get_string(&line[6], &i1_str, &i2_str, &size, 1)) != NULL )
             {
             zlabel = xmalloc(size + 1);
             strcpy(zlabel, string);
@@ -762,7 +805,7 @@ void ReadParamFile ( void )
       else if ( strncmp(line, "title", 5) == 0 )
          {
          size = strlen(&line[5]);
-         if ( (string = get_string(&line[5], &size)) != NULL )
+         if ( (string = get_string(&line[5], &i1_str, &i2_str, &size, 1)) != NULL )
             {
             title = xmalloc(size + 1);
             strcpy(title, string);
@@ -786,7 +829,7 @@ void ReadParamFile ( void )
          if ( ibinvalue <= nplots )
             {
             size = strlen(&line[9]);
-            if ( (string = get_string(&line[9], &size)) != NULL )
+            if ( (string = get_string(&line[9], &i1_str, &i2_str, &size, 0)) != NULL )
                {
                strncpy(&bin_values[index_bin_values], string, 8);
                index_bin_values = index_bin_values + 9;
@@ -800,7 +843,7 @@ void ReadParamFile ( void )
          if ( ibinref <= nplots )
             {
             size = strlen(&line[7]);
-            if ( (string = get_string(&line[7], &size)) != NULL )
+            if ( (string = get_string(&line[7], &i1_str, &i2_str, &size, 0)) != NULL )
                {
                strncpy(&bin_refs[index_bin_refs], string, 8);
                index_bin_refs = index_bin_refs + 9;
@@ -895,7 +938,7 @@ void ReadParamFile ( void )
             else
                {
                size = strlen(&line[5]);
-               if ( (string = get_string(&line[5], &size)) != NULL )
+               if ( (string = get_string(&line[5], &i1_str, &i2_str, &size, 0)) != NULL )
                   {
                   strncpy(&stemflags[index_stemflags], string, 3);
                   index_stemflags = index_stemflags + 4;
@@ -907,14 +950,14 @@ void ReadParamFile ( void )
       else if ( strncmp(line, "date_time", 9) == 0 )
          {
          size = strlen(&line[9]);
-         if ( (string = get_string(&line[9], &size)) != NULL )
+         if ( (string = get_string(&line[9], &i1_str, &i2_str, &size, 0)) != NULL )
             strncpy(&p_plot_param->date_time_anchor[0], string, 9);
          }
 
       else if ( strncmp(line, "save_close", 10) == 0 )
          {
          size = strlen(&line[10]);
-         if ( (string = get_string(&line[10], &size)) != NULL )
+         if ( (string = get_string(&line[10], &i1_str, &i2_str, &size, 0)) != NULL )
             {
             save_filename = xmalloc(size + 1);
             strcpy(save_filename, string);
@@ -925,62 +968,13 @@ void ReadParamFile ( void )
       else if ( strncmp(line, "save", 4) == 0 )
          {
          size = strlen(&line[4]);
-         if ( (string = get_string(&line[4], &size)) != NULL )
+         if ( (string = get_string(&line[4], &i1_str, &i2_str, &size, 0)) != NULL )
             {
             save_filename = xmalloc(size + 1);
             strcpy(save_filename, string);
             }
          }
 
-      else if ( strncmp(line, "plot_box", 8) == 0 )
-         {
-         size = strlen(&line[8]);
-         if ( (string = get_string(&line[8], &size)) != NULL )
-            strncpy(&p_plot_param->plot_box[0], string, 3);
-         }
-
-      else if ( strncmp(line, "x_tick_marks", 12) == 0 )
-         {
-         size = strlen(&line[12]);
-         if ( (string = get_string(&line[12], &size)) != NULL )
-            strncpy(&p_plot_param->x_tick_marks[0], string, 3);
-         }
-
-      else if ( strncmp(line, "y_tick_marks", 12) == 0 )
-         {
-         size = strlen(&line[12]);
-         if ( (string = get_string(&line[12], &size)) != NULL )
-            strncpy(&p_plot_param->y_tick_marks[0], string, 3);
-         }
-
-      else if ( strncmp(line, "z_tick_marks", 12) == 0 )
-         {
-         size = strlen(&line[12]);
-         if ( (string = get_string(&line[12], &size)) != NULL )
-            strncpy(&p_plot_param->z_tick_marks[0], string, 3);
-         }
-
-      else if ( strncmp(line, "x_tick_labels", 13) == 0 )
-         {
-         size = strlen(&line[13]);
-         if ( (string = get_string(&line[13], &size)) != NULL )
-            strncpy(&p_plot_param->x_tick_labels[0], string, 3);
-         }
-
-      else if ( strncmp(line, "y_tick_labels", 13) == 0 )
-         {
-         size = strlen(&line[13]);
-         if ( (string = get_string(&line[13], &size)) != NULL )
-            strncpy(&p_plot_param->y_tick_labels[0], string, 3);
-         }
-
-      else if ( strncmp(line, "z_tick_labels", 13) == 0 )
-         {
-         size = strlen(&line[13]);
-         if ( (string = get_string(&line[13], &size)) != NULL )
-            strncpy(&p_plot_param->z_tick_labels[0], string, 3);
-         }
-
       else if ( strncmp(line, "window_size", 11) == 0 )
          {
          if ( sscanf(&line[11], "%d %d", &p_window_data->width, &p_window_data->height ) != 2 )
@@ -990,10 +984,59 @@ void ReadParamFile ( void )
             }
          }
 
+      else if ( strncmp(line, "plot_box", 8) == 0 )
+         {
+         size = strlen(&line[8]);
+         if ( (string = get_string(&line[8], &i1_str, &i2_str, &size, 0)) != NULL )
+            strncpy(&p_plot_param->plot_box[0], string, 3);
+         }
+
+      else if ( strncmp(line, "x_tick_marks", 12) == 0 )
+         {
+         size = strlen(&line[12]);
+         if ( (string = get_string(&line[12], &i1_str, &i2_str, &size, 0)) != NULL )
+            strncpy(&p_plot_param->x_tick_marks[0], string, 3);
+         }
+
+      else if ( strncmp(line, "y_tick_marks", 12) == 0 )
+         {
+         size = strlen(&line[12]);
+         if ( (string = get_string(&line[12], &i1_str, &i2_str, &size, 0)) != NULL )
+            strncpy(&p_plot_param->y_tick_marks[0], string, 3);
+         }
+
+      else if ( strncmp(line, "z_tick_marks", 12) == 0 )
+         {
+         size = strlen(&line[12]);
+         if ( (string = get_string(&line[12], &i1_str, &i2_str, &size, 0)) != NULL )
+            strncpy(&p_plot_param->z_tick_marks[0], string, 3);
+         }
+
+      else if ( strncmp(line, "x_tick_labels", 13) == 0 )
+         {
+         size = strlen(&line[13]);
+         if ( (string = get_string(&line[13], &i1_str, &i2_str, &size, 0)) != NULL )
+            strncpy(&p_plot_param->x_tick_labels[0], string, 3);
+         }
+
+      else if ( strncmp(line, "y_tick_labels", 13) == 0 )
+         {
+         size = strlen(&line[13]);
+         if ( (string = get_string(&line[13], &i1_str, &i2_str, &size, 0)) != NULL )
+            strncpy(&p_plot_param->y_tick_labels[0], string, 3);
+         }
+
+      else if ( strncmp(line, "z_tick_labels", 13) == 0 )
+         {
+         size = strlen(&line[13]);
+         if ( (string = get_string(&line[13], &i1_str, &i2_str, &size, 0)) != NULL )
+            strncpy(&p_plot_param->z_tick_labels[0], string, 3);
+         }
+
       else if ( strncmp(line, "font_name", 9) == 0 )
          {
          size = strlen(&line[9]);
-         if ( (string = get_string(&line[9], &size)) != NULL )
+         if ( (string = get_string(&line[9], &i1_str, &i2_str, &size, 0)) != NULL )
             {
             free(font_name);
             font_name = xmalloc(size + 1);
