@@ -14,7 +14,7 @@
 *
 * Functions for View menu items.
 *
-* Copyright  2008, 2009, 2010 Spencer A. Buckner
+* Copyright  2008, 2009, 2010, 2011 Spencer A. Buckner
 * http://savannah.gnu.org/projects/gsegrafix
 *
 * This file is part of GSEGrafix, a scientific and engineering plotting program.
@@ -305,6 +305,7 @@ void ViewAxesCallback ( GtkEntry *entry_box )
          if ( strcmp(p_plot_param->axis_type, "linear") == 0 &&
               strcmp(p_plot_param->axis_scale, "equal") == 0 )
             AxesEqual(0);
+         DrawBackgroundImage();
          DrawGrid2d();
          DrawGridLog();
          PlotData2d();
@@ -338,6 +339,7 @@ void ViewAxesCallback ( GtkEntry *entry_box )
 
          /* Draw plot */
          AxisLimits(0);
+         DrawBackgroundImage();
          PolarPlot();
          DrawLegend();
          DrawText();
@@ -475,8 +477,8 @@ void ViewRotateCallback ( GtkEntry *entry_box )
 
 
 /* Declare external variables */
-extern GtkWidget *axes_menu_item;
-int ncontour_plots;
+extern GtkWidget *axes_menu_item, *xy_coords_menu_item;
+int ncolor_plots, ncontour_plots;
 
 
 void ViewLabelHandler ( void )
@@ -491,6 +493,20 @@ void ViewLabelHandler ( void )
    window = (GtkWidget *) p_window_data->window;
    if ( contour_labels_flag == 0 )
       {
+      /* Turn xy_coords_display off */
+      if ( coords_display_flag == 1 )
+         {
+         coords_display_flag = 0;
+         if ( gdk_pointer_is_grabbed() == TRUE )
+            gdk_pointer_ungrab(GDK_CURRENT_TIME);
+         if ( G_IS_OBJECT(GTK_OBJECT(text_plot_data)) )
+            gtk_object_destroy(GTK_OBJECT(text_plot_data));
+         if ( G_IS_OBJECT(GTK_OBJECT(text_xy_coords_data)) )
+            gtk_object_destroy(GTK_OBJECT(text_xy_coords_data));
+         if ( G_IS_OBJECT(GTK_OBJECT(text_z_coords_data)) )
+            gtk_object_destroy(GTK_OBJECT(text_z_coords_data));
+         }
+
       /* Get number of contour plots */
       nplots = p_plot_param->nplots;
       icount = 0;
@@ -511,11 +527,12 @@ void ViewLabelHandler ( void )
                                                 "anchor", GTK_ANCHOR_NORTH_WEST,
                                                 "justification", GTK_JUSTIFY_LEFT,
                                                 "font-desc", font_text,
-                                                "fill_color_rgba", 0x000000FF,
+                                                "fill_color_rgba", canvas_fg_color,
                                                 NULL);
 
-      /* Set axes menu-item sensitivity */
+      /* Set axes and xy_coords menu-items sensitivity */
       gtk_widget_set_sensitive(axes_menu_item, FALSE);
+      gtk_widget_set_sensitive(xy_coords_menu_item, FALSE);
       }
 
    else if ( contour_labels_flag == 1 )
@@ -526,9 +543,9 @@ void ViewLabelHandler ( void )
          gdk_pointer_ungrab(GDK_CURRENT_TIME);
       if ( G_IS_OBJECT(GTK_OBJECT(text_contour_data)) )
          gtk_object_destroy(GTK_OBJECT(text_contour_data));
-      if ( coords_display_flag == 0 )
-         gdk_window_set_cursor((GdkWindow *) window->window, NULL);
+      gdk_window_set_cursor((GdkWindow *) window->window, NULL);
       gtk_widget_set_sensitive(axes_menu_item, TRUE);
+      gtk_widget_set_sensitive(xy_coords_menu_item, TRUE);
       }
 
    return;
@@ -552,7 +569,7 @@ void ViewLabelCallback ( int inc )
    contour_label = NULL;
 
 
-   /* Check icontour value */
+   /* Check icontour_plots value */
    icontour_plots = icontour_plots + inc;
    if ( icontour_plots < 1 )
       icontour_plots = 1;
@@ -652,6 +669,7 @@ void ViewLabelCallback ( int inc )
 void ViewCoordsDisplayHandler ( void )
    {
    /* Declare variables */
+   int iplot, nplots, icount_color, icount_contour;
    GtkWidget *window;
    GdkCursor *cursor;
 
@@ -660,11 +678,43 @@ void ViewCoordsDisplayHandler ( void )
    window = (GtkWidget *) p_window_data->window;
    if ( coords_display_flag == 0 )
       {
-      coords_display_flag = 1;
+      /* Get number of color and contour plots */
+      nplots = p_plot_param->nplots;
+      plot_type_data = xmalloc(nplots*sizeof(int));
+      icount_color = 0;
+      icount_contour = 0;
+      for ( iplot=1; iplot<=nplots; iplot++ )
+         {
+         if ( strcmp(&plot_types[(iplot-1)*10], "color") == 0 )
+            {
+            icount_color++;
+            plot_type_data[iplot-1] = icount_color;
+            }
+         else if ( strcmp(&plot_types[(iplot-1)*10], "contour") == 0 )
+            {
+            icount_contour++;
+            plot_type_data[iplot-1] = -icount_contour;
+            }
+         else
+            plot_type_data[iplot-1] = 0;
+         }
 
       /* Set cursor and initialize text canvas item */
+      coords_display_flag = 1;
+      itotal_plots = 1;
+      icolor_plots = 1;
+      icontour_plots = 1;
       cursor = gdk_cursor_new(GDK_CROSSHAIR);
       gdk_window_set_cursor((GdkWindow *) window->window, cursor);
+      text_plot_data = gnome_canvas_item_new(group,
+                                             GNOME_TYPE_CANVAS_TEXT,
+                                             "x", 10.0,
+                                             "y", 10.0,
+                                             "anchor", GTK_ANCHOR_NORTH_WEST,
+                                             "justification", GTK_JUSTIFY_LEFT,
+                                             "font-desc", font_text,
+                                             "fill_color_rgba", canvas_fg_color,
+                                             NULL);
       text_xy_coords_data = gnome_canvas_item_new(group,
                                                   GNOME_TYPE_CANVAS_TEXT,
                                                   "x", 10.0,
@@ -672,38 +722,67 @@ void ViewCoordsDisplayHandler ( void )
                                                   "anchor", GTK_ANCHOR_SOUTH_WEST,
                                                   "justification", GTK_JUSTIFY_LEFT,
                                                   "font-desc", font_text,
-                                                  "fill_color_rgba", 0x000000FF,
+                                                  "fill_color_rgba", canvas_fg_color,
                                                   NULL);
+      text_z_coords_data = gnome_canvas_item_new(group,
+                                                 GNOME_TYPE_CANVAS_TEXT,
+                                                 "anchor", GTK_ANCHOR_NORTH,
+                                                 "justification", GTK_JUSTIFY_CENTER,
+                                                 "font-desc", font_text,
+                                                 "fill_color_rgba", canvas_fg_color,
+                                                 NULL);
+
+      /* Set axes menu-item sensitivity */
+      gtk_widget_set_sensitive(axes_menu_item, FALSE);
       }
 
    else if ( coords_display_flag == 1 )
       {
       coords_display_flag = 0;
+      itotal_plots = 1;
+      icolor_plots = 1;
+      icontour_plots = 1;
+      free(plot_type_data);
       if ( gdk_pointer_is_grabbed() == TRUE )
          gdk_pointer_ungrab(GDK_CURRENT_TIME);
+      if ( G_IS_OBJECT(GTK_OBJECT(text_plot_data)) )
+         gtk_object_destroy(GTK_OBJECT(text_plot_data));
       if ( G_IS_OBJECT(GTK_OBJECT(text_xy_coords_data)) )
          gtk_object_destroy(GTK_OBJECT(text_xy_coords_data));
-      if ( contour_labels_flag == 0 )
-         gdk_window_set_cursor((GdkWindow *) window->window, NULL);
+      if ( G_IS_OBJECT(GTK_OBJECT(text_z_coords_data)) )
+         gtk_object_destroy(GTK_OBJECT(text_z_coords_data));
+      gdk_window_set_cursor((GdkWindow *) window->window, NULL);
+      gtk_widget_set_sensitive(axes_menu_item, TRUE);
       }
 
    return;
    }
 
 
-void ViewCoordsDisplayCallback ( void )
+void ViewCoordsDisplayCallback ( int inc )
    {
-   int nxvalues, nyvalues;
+   int i, nplots, nxvalues, nyvalues,
+       nx, ny, xindex, yindex, zindex;
    double x1_box, x2_box, y1_box, y2_box,
           xmin, xmax, ymin, ymax, xscale, yscale,
           window_width, window_height, xorigin, yorigin, radius,
           rmin, rmax, rscale, rx, ry;
-   static double x, y, theta, r;
+   static double x, y, z, theta, r;
 
 
    /* Initialize pointers */
    xy_coords_data[0] = NULL;
    xy_coords_data[1] = NULL;
+   z_coords_data = NULL;
+
+
+   /* Check itotal_plots value */
+   nplots = p_plot_param->nplots;
+   itotal_plots = itotal_plots + inc;
+   if ( itotal_plots < 1 )
+      itotal_plots = 1;
+   else if ( itotal_plots > nplots )
+      itotal_plots = nplots;
 
 
    /* Get plot box minimum and maximum values */
@@ -730,16 +809,59 @@ void ViewCoordsDisplayCallback ( void )
    if ( flag_2d_rect == 1 )
       {
       /* Get axis minimum and maximum values for 2d rectangular coordinates */
-      nxvalues = p_ticklabels->nxvalues;
-      nyvalues = p_ticklabels->nyvalues;
-      xmin = p_ticklabels->xvalues[0];
-      xmax = p_ticklabels->xvalues[nxvalues-1];
-      ymin = p_ticklabels->yvalues[0];
-      ymax = p_ticklabels->yvalues[nyvalues-1];
-      xmin = xmin - p_ticklabels->xoffset1;
-      xmax = xmax + p_ticklabels->xoffset2;
-      ymin = ymin - p_ticklabels->yoffset1;
-      ymax = ymax + p_ticklabels->yoffset2;
+      if ( strcmp(p_plot_param->axis_type, "linear") == 0 )
+         {
+         nxvalues = p_ticklabels->nxvalues;
+         xmin = p_ticklabels->xvalues[0];
+         xmax = p_ticklabels->xvalues[nxvalues-1];
+         nyvalues = p_ticklabels->nyvalues;
+         ymin = p_ticklabels->yvalues[0];
+         ymax = p_ticklabels->yvalues[nyvalues-1];
+         xmin = xmin - p_ticklabels->xoffset1;
+         xmax = xmax + p_ticklabels->xoffset2;
+         ymin = ymin - p_ticklabels->yoffset1;
+         ymax = ymax + p_ticklabels->yoffset2;
+         }
+
+      else if ( strcmp(p_plot_param->axis_type, "semilogx") == 0 )
+         {
+         nxvalues = p_ticklabels->nxvalues;
+         xmin = floor(p_ticklabels->xvalues[0]);
+         xmax = ceil(p_ticklabels->xvalues[nxvalues-1]);
+         nxvalues = roundint(xmax - xmin + 1.0);
+         nyvalues = p_ticklabels->nyvalues;
+         ymin = p_ticklabels->yvalues[0];
+         ymax = p_ticklabels->yvalues[nyvalues-1];
+         ymin = ymin - p_ticklabels->yoffset1;
+         ymax = ymax + p_ticklabels->yoffset2;
+         }
+
+      else if ( strcmp(p_plot_param->axis_type, "semilogy") == 0 )
+         {
+         nxvalues = p_ticklabels->nxvalues;
+         xmin = p_ticklabels->xvalues[0];
+         xmax = p_ticklabels->xvalues[nxvalues-1];
+         nyvalues = p_ticklabels->nyvalues;
+         ymin = floor(p_ticklabels->yvalues[0]);
+         ymax = ceil(p_ticklabels->yvalues[nyvalues-1]);
+         nyvalues = roundint(ymax - ymin + 1.0);
+         xmin = xmin - p_ticklabels->xoffset1;
+         xmax = xmax + p_ticklabels->xoffset2;
+         }
+
+      else if ( strcmp(p_plot_param->axis_type, "loglog") == 0 )
+         {
+         nxvalues = p_ticklabels->nxvalues;
+         xmin = floor(p_ticklabels->xvalues[0]);
+         xmax = ceil(p_ticklabels->xvalues[nxvalues-1]);
+         nxvalues = roundint(xmax - xmin + 1.0);
+         nyvalues = p_ticklabels->nyvalues;
+         ymin = floor(p_ticklabels->yvalues[0]);
+         ymax = ceil(p_ticklabels->yvalues[nyvalues-1]);
+         nyvalues = roundint(ymax - ymin + 1.0);
+         }
+
+      /* Calculate axis scale factors */
       xscale = (x2_box - x1_box)/(xmax - xmin);
       yscale = (y2_box - y1_box)/(ymax - ymin);
       }
@@ -777,6 +899,62 @@ void ViewCoordsDisplayCallback ( void )
          xy_coords_data[0] = &x;
          xy_coords_data[1] = &y;
          }
+
+      /* Interpolate z-axis data for color plots */
+      if ( plot_type_data[itotal_plots-1] > 0 )
+         {
+         xindex = 0;
+         yindex = 0;
+         zindex = 0;
+         nx = 0;
+         ny = 0;
+         icolor_plots = plot_type_data[itotal_plots-1];
+         for ( i=1; i<=icolor_plots; i++ )
+            {
+            xindex = xindex + nx;
+            yindex = yindex + ny;
+            zindex = zindex + nx*ny;
+            nx = nxcolor[i-1];
+            ny = nycolor[i-1];
+            }
+         if ( xcolor[xindex] <= x && x <= xcolor[xindex+nx-1] &&
+              ycolor[yindex] <= y && y <= ycolor[yindex+ny-1] )
+            {
+            interp2(nx, ny, 1, &xcolor[xindex], &ycolor[yindex], &zcolor[zindex], &x, &y, &z);
+            z_coords_data = &z;
+            }
+         else
+            z_coords_data = NULL;
+         return;
+         }
+
+      /* Interpolate z-axis data for contour plots */
+      else if ( plot_type_data[itotal_plots-1] < 0 )
+         {
+         xindex = 0;
+         yindex = 0;
+         zindex = 0;
+         nx = 0;
+         ny = 0;
+         icontour_plots = -plot_type_data[itotal_plots-1];
+         for ( i=1; i<=icontour_plots; i++ )
+            {
+            xindex = xindex + nx;
+            yindex = yindex + ny;
+            zindex = zindex + nx*ny;
+            nx = nxcontour[i-1];
+            ny = nycontour[i-1];
+            }
+         if ( xcontour[xindex] <= x && x <= xcontour[xindex+nx-1] &&
+              ycontour[yindex] <= y && y <= ycontour[yindex+ny-1] )
+            {
+            interp2(nx, ny, 1, &xcontour[xindex], &ycontour[yindex], &zcontour[zindex], &x, &y, &z);
+            z_coords_data = &z;
+            }
+         else
+            z_coords_data = NULL;
+         return;
+         }
       }
 
    else if ( flag_polar == 1 )
@@ -796,8 +974,7 @@ void ViewCoordsDisplayCallback ( void )
          theta = theta + 360.0;
       xy_coords_data[0] = &theta;
       xy_coords_data[1] = &r;
+      return;
       }
-
-   return;
    }
 
